@@ -6,7 +6,7 @@ These are definitions of abstract terms into code
 ## Rate
 Rate of occurance
 ```
-use rpgstat::attributes::Rate;
+use rpg_stat::attributes::Rate;
 let yes:Rate = Rate::Always;
 assert_eq!(yes.worked(), true);
 let no:Rate = Rate::None;
@@ -20,7 +20,7 @@ let hmmm:Rate = Rate::Some;
 We can easily find the value of an effectiveness:
 
 ```
-use rpgstat::attributes::{Effectiveness, Value};
+use rpg_stat::attributes::{Effectiveness, Value};
 let hp:i32 = 50;
 // later on we use an item and check the effectiveness of it
 assert_eq!(Effectiveness::Half.value(hp), 25);
@@ -28,7 +28,7 @@ assert_eq!(Effectiveness::Half.value(hp), 25);
 ```
 This effectiveness can be stored in a struct and you could implement a wrapper for `value(T)`:
 ```
-use rpgstat::attributes::{Effectiveness, Value};
+use rpg_stat::attributes::{Effectiveness, Value};
 
 pub struct Item {
     pub name:String,
@@ -45,24 +45,32 @@ impl Item {
 
 ## Stage
 ```
-use rpgstat::attributes::{Stage, Value};
+use rpg_stat::attributes::{Stage, Value};
 let stage:Stage = Stage::Baby.value(15);
 //
 assert_eq!(stage, Stage::Teen);
 
 ```
+
+
 */
 use std::fmt;
 use std::fmt::Debug;
-use std::fmt::Display;
 use std::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Neg, Rem, RemAssign, Sub, SubAssign};
 extern crate num;
-//use num::NumCast;
 use serde::{Deserialize, Serialize};
-//use strum::IntoEnumIterator;
-use strum_macros::EnumIter;
+
+#[cfg(feature = "fltkform")]
+use fltk::{prelude::*, *};
+#[cfg(feature = "fltkform")]
+use fltk_form_derive::*;
+#[cfg(feature = "fltkform")]
+use fltk_form::{FltkForm, HasProps};
+
+// our modules
 use crate::random::Random;
 
+
 /*
 # Rate
 
@@ -71,13 +79,14 @@ This can be used to determine the Rate at which enemies/items appear in areas, o
 To find a random true/false value simple call `worked()` on your enum
 
 ```
-use rpgstat::attributes::Rate;
+use rpg_stat::attributes::Rate;
 let yes:Rate = Rate::Always;
 assert_eq!(yes.worked(), true);
+assert_eq!(Rate::None::worked(), false);
 ```
-
 */
-#[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter, Deserialize, Serialize)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
 pub enum Rate {
     /// 100%
     Always,
@@ -94,11 +103,27 @@ pub enum Rate {
     /// 0%
     None,
 }
-impl Random for Rate{}
+impl Random for Rate{
+    type Type = Rate;
+    fn random_type(&self) -> Self::Type {
+        let max = 7;
+        let val = self.random_rate(max);
+        match val {
+            0 => Rate::None,
+            1 => Rate::Often,
+            3 => Rate::Hardly,
+            4 => Rate::Some,
+            5 => Rate::Barely,
+            7 => Rate::Always,
+            _=> Rate::Usually,
+        }
+    }
+}
 impl Rate {
     /*
     
     */
+    #[allow(unused)]
     pub fn worked(&self) -> bool {
         match *self {
             Rate::Always => true, // 100%
@@ -131,25 +156,39 @@ impl fmt::Display for Rate {
 # Effectiveness
 
 ```rs
-use rpgstat::attributes::{Effectiveness, Value};
+use rpg_stat::attributes::{Effectiveness, Value};
 let hp:i32 = 50;
 // later on we use an item and check the effectiveness of it
 assert_eq!(Effectiveness::Half.value(hp), 25);
 
 ```
 */
-#[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter, Deserialize, Serialize)]
-pub enum Effectiveness {
-    
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
+pub enum Effectiveness {    
     Double,
     HalfExtra,
     Half,
     Normal,
     None,
 }
+impl Random for Effectiveness{
+    type Type = Effectiveness;
+    fn random_type(&self) -> Self::Type {
+        let max = 6;
+        let val = self.random_rate(max);
+        match val {
+            0 => Effectiveness::Double,
+            1 => Effectiveness::HalfExtra,
+            4 => Effectiveness::Half,
+            5 => Effectiveness::Normal,
+            _=> Effectiveness::None,
+        }
+    }
+}
 impl<T:Copy
-    + Display
     + Default
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
@@ -196,7 +235,8 @@ impl fmt::Display for Effectiveness {
         write!(f, "{}", v.as_str())
     }
 }
-#[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter, Deserialize, Serialize)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
 /// This is the 'stage' of life the creature is in
 /// Stages of life are similar to Pokemon evolution,
 /// however our creatures cannot change species randomly
@@ -212,6 +252,23 @@ pub enum Stage {
     Older,
     Old,
 }
+impl Random for Stage{
+    type Type = Stage;
+    fn random_type(&self) -> Self::Type {
+        let max = 8;
+        let val = self.random_rate(max);
+        match val {
+            0 => Stage::Toddler,
+            1 => Stage::Kid,
+            3 => Stage::Teen,
+            4 => Stage::Young,
+            5 => Stage::Grown,
+            7 => Stage::Older,
+            8 => Stage::Old,
+            _=> Stage::Baby,
+        }
+    }
+}
 impl Stage {
     /// Default to empty
     #[allow(dead_code)]
@@ -219,9 +276,9 @@ impl Stage {
         Self::Teen
     }
 }
-impl<T:Copy 
+impl<T:Copy
     + Default
-    + Display
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
@@ -261,8 +318,8 @@ impl<T:Copy
 }
 
 pub trait Value<T:Copy
-    + Display
     + Default
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
