@@ -6,18 +6,29 @@ This composes the various Effects in-game related to a character's Stats
 */
 use std::fmt;
 use std::fmt::Debug;
-//use std::fmt::Display;
-//use std::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Neg, Rem, RemAssign, Sub, SubAssign};
 extern crate num;
-//use num::NumCast;
 use serde::{Deserialize, Serialize};
-//use strum::IntoEnumIterator;
-use strum_macros::EnumIter;
+
+#[cfg(feature = "fltkform")]
+use fltk::{prelude::*, *};
+#[cfg(feature = "fltkform")]
+use fltk_form_derive::*;
+#[cfg(feature = "fltkform")]
+use fltk_form::FltkForm;
+
+use crate::random::Random;
+
+#[cfg(feature = "makesvg")]
+use svg::node::element::Group as SvgGroup;
+#[cfg(feature = "makesvg")]
+use crate::body::VectorView;
+
 /*
 # Basic 
 
 */
-#[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter, Deserialize, Serialize)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
 pub enum Basic {
     /// no effect aka a player or something else that should not have an effect, like a key
     None,
@@ -48,11 +59,27 @@ impl fmt::Display for Basic {
         write!(f, "{}", v.as_str())
     }
 }
+impl Random for Basic {
+    type Type = Basic;
+    fn random_type(&self) -> Self::Type {
+        let max = 4;
+        let val = self.random_rate(max);
+        match val {
+            0 => Basic::HP,
+            1 => Basic::MP,
+            2 => Basic::XP,
+            3 => Basic::GP,
+            _=> Basic::None,
+        }
+    }
+}
+
 /*
 # Normal 
 
 */
-#[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter, Deserialize, Serialize)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
 pub enum Normal {
     /// no effect aka a player or something else that should not have an effect, like a key
     None,
@@ -119,13 +146,38 @@ impl fmt::Display for Normal {
         write!(f, "{}", v.as_str())
     }
 }
-
+impl Random for Normal {
+    type Type = Normal;
+    fn random_type(&self) -> Self::Type {
+        let max = 15;
+        let val = self.random_rate(max);
+        match val {
+            0 => Normal::HP,
+            1 => Normal::MP,
+            2 => Normal::XP,
+            3 => Normal::GP,
+            4 => Normal::Burn,
+            5 => Normal::Poison,
+            7 => Normal::Freeze,
+            8 => Normal::Sick,
+            9 => Normal::Sap,
+            10 => Normal::Bless,
+            11 => Normal::Heal,
+            12 => Normal::Stuck,
+            13 => Normal::Bound,
+            14 => Normal::Blocked,
+            15 => Normal::Locked,
+            _=> Normal::None,
+        }
+    }
+}
 /*
 # Advanced 
 
 */
 //TODO more effects
-#[derive(Debug, Clone, Copy, PartialEq, Eq, EnumIter, Deserialize, Serialize)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
 pub enum Advanced {
     /// no effect aka a player or something else that should not have an effect, like a key
     None,
