@@ -129,36 +129,52 @@ Fight mechanics:
  * Items, Weapons, Armor, etc may be formulated for specific age ranges and prevent users who are too young or old to use them.
 
 Story mechanics:
- * Age can influence story mechanics but this would be a choice
+ * Age could potentially influence story mechanics, being to young to leave an area would promote grinding.
 
  */
 use std::default::Default;
 use serde::{Deserialize, Serialize};
 extern crate num;
-//use num::NumCast;
+
 use std::ops::{Add, AddAssign,  Div, DivAssign, Mul, MulAssign, Neg, Rem, RemAssign, Sub, SubAssign};
+use std::fmt::Debug;
+
+#[cfg(feature = "fltkform")]
+use fltk::{prelude::*, *};
+#[cfg(feature = "fltkform")]
+use fltk_form_derive::*;
+#[cfg(feature = "fltkform")]
+use fltk_form::{FltkForm, HasProps};
+#[cfg(feature = "fltkform")]
+use std::collections::HashMap;
+#[cfg(feature = "fltkform")]
+use std::mem::transmute;
+
+
+use crate::random::*;
 
 /*
 # Builder
 
-The builder trait is how I create `rpgstat::stats::{Basic,Normal,Advance}` from enums
+The builder trait is how I create `rpg_stat::stats::{Basic,Normal,Advance}` from enums
 
 */
-pub trait Builder<T:Copy 
-                  + Default
-                  + AddAssign
-                  + Add<Output = T>
-                  + Div<Output = T>
-                  + DivAssign
-                  + Mul<Output = T>
-                  + MulAssign
-                  + Neg<Output = T>
-                  + Rem<Output = T>
-                  + RemAssign
-                  + Sub<Output = T>
-                  + SubAssign
-                  + std::cmp::PartialOrd
-                  + num::NumCast> {
+pub trait Builder <T:Copy
+    + Default
+    + Debug
+    + AddAssign
+    + Add<Output = T>
+    + Div<Output = T>
+    + DivAssign
+    + Mul<Output = T>
+    + MulAssign
+    + Neg<Output = T>
+    + Rem<Output = T>
+    + RemAssign
+    + Sub<Output = T>
+    + SubAssign
+    + std::cmp::PartialOrd
+    + num::NumCast> {
     /// Build a `Basic` stat
     fn build_basic(&self, id:T, level:T) -> Basic<T>;
     // Build a `Normal` stat
@@ -171,21 +187,22 @@ pub trait Builder<T:Copy
 Premade trait for Basic Stat
 You simply define the function `stat()` to return the `Basic<T>` associated with your code.
 */
-pub trait BasicPremade<T:Copy 
-                      + Default
-                      + AddAssign
-                      + Add<Output = T>
-                      + Div<Output = T>
-                      + DivAssign
-                      + Mul<Output = T>
-                      + MulAssign
-                      + Neg<Output = T>
-                      + Rem<Output = T>
-                      + RemAssign
-                      + Sub<Output = T>
-                      + SubAssign
-                      + std::cmp::PartialOrd
-                      + num::NumCast> {
+pub trait BasicPremade<T:Copy
+    + Default
+    + Debug
+    + AddAssign
+    + Add<Output = T>
+    + Div<Output = T>
+    + DivAssign
+    + Mul<Output = T>
+    + MulAssign
+    + Neg<Output = T>
+    + Rem<Output = T>
+    + RemAssign
+    + Sub<Output = T>
+    + SubAssign
+    + std::cmp::PartialOrd
+    + num::NumCast> {
     /// # Function you need to imlement
     /// stat returns the `Basic<T>` you created
     fn stat(&self) -> Basic<T>;
@@ -279,22 +296,24 @@ pub trait BasicPremade<T:Copy
 
 This basic model of stats is easy to work with for beginners, but powerful enough to be used by the most experienced.
 */
+
 #[derive( Debug, Clone, Copy, PartialEq, Serialize, Deserialize)]
-pub struct Basic<T:Copy 
-                 + Default
-                 + AddAssign
-                 + Add<Output = T>
-                 + Div<Output = T>
-                 + DivAssign
-                 + Mul<Output = T>
-                 + MulAssign
-                 + Neg<Output = T>
-                 + Rem<Output = T>
-                 + RemAssign
-                 + Sub<Output = T>
-                 + SubAssign
-                 + std::cmp::PartialOrd
-                 + num::NumCast> {
+pub struct Basic<T:Copy
+    + Default
+    + Debug
+    + AddAssign
+    + Add<Output = T>
+    + Div<Output = T>
+    + DivAssign
+    + Mul<Output = T>
+    + MulAssign
+    + Neg<Output = T>
+    + Rem<Output = T>
+    + RemAssign
+    + Sub<Output = T>
+    + SubAssign
+    + std::cmp::PartialOrd
+    + num::NumCast> {
     /// Identification Number
     pub id:T,
     /// Experience Points
@@ -316,8 +335,9 @@ pub struct Basic<T:Copy
     /// your currency points
     pub gp:T,
 }
-impl<T:Copy 
+impl<T:Copy
     + Default
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
@@ -348,8 +368,9 @@ impl<T:Copy
         }
     }
 }
-impl<T:Copy 
+impl<T:Copy
     + Default
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
@@ -373,21 +394,22 @@ impl<T:Copy
 Premade trait for Normal Stat
 You simply define the function `stat()` to return the `Normal<T>` associated with your code.
 */
-pub trait NormalPremade<T:Copy 
-                      + Default
-                      + AddAssign
-                      + Add<Output = T>
-                      + Div<Output = T>
-                      + DivAssign
-                      + Mul<Output = T>
-                      + MulAssign
-                      + Neg<Output = T>
-                      + Rem<Output = T>
-                      + RemAssign
-                      + Sub<Output = T>
-                      + SubAssign
-                      + std::cmp::PartialOrd
-                      + num::NumCast> {
+pub trait NormalPremade<T:Copy
+    + Default
+    + Debug
+    + AddAssign
+    + Add<Output = T>
+    + Div<Output = T>
+    + DivAssign
+    + Mul<Output = T>
+    + MulAssign
+    + Neg<Output = T>
+    + Rem<Output = T>
+    + RemAssign
+    + Sub<Output = T>
+    + SubAssign
+    + std::cmp::PartialOrd
+    + num::NumCast> {
     /// # Function you need to imlement
     /// stat returns the `Normal<T>` you created
     fn stat(&self) -> Normal<T>;
@@ -517,13 +539,11 @@ pub trait NormalPremade<T:Copy
     fn attack(&self, other:Normal<T>) -> T {
         let val = self.atk();
         let mut res = val * val;
-        let mut def = other.def;
-        def += val;
+        let def = other.def + val;
         res /= def;
         res
     }
 }
-
 /*
 # The Normal
 
@@ -635,25 +655,27 @@ impl<T:Copy
         Self::empty::<T>()
     }
 }
+
 /*
 Premade trait for Advanced Stat
 You simply define the function `stat()` to return the `Advanced<T>` associated with your code.
 */
-pub trait AdvancedPremade<T:Copy 
-                      + Default
-                      + AddAssign
-                      + Add<Output = T>
-                      + Div<Output = T>
-                      + DivAssign
-                      + Mul<Output = T>
-                      + MulAssign
-                      + Neg<Output = T>
-                      + Rem<Output = T>
-                      + RemAssign
-                      + Sub<Output = T>
-                      + SubAssign
-                      + std::cmp::PartialOrd
-                      + num::NumCast> {
+pub trait AdvancedPremade<T:Copy
+    + Default
+    + Debug
+    + AddAssign
+    + Add<Output = T>
+    + Div<Output = T>
+    + DivAssign
+    + Mul<Output = T>
+    + MulAssign
+    + Neg<Output = T>
+    + Rem<Output = T>
+    + RemAssign
+    + Sub<Output = T>
+    + SubAssign
+    + std::cmp::PartialOrd
+    + num::NumCast> {
     /// # Function you need to imlement
     /// stat returns the `Advanced<T>` you created
     fn stat(&self) -> Advanced<T>;
@@ -826,21 +848,22 @@ pub trait AdvancedPremade<T:Copy
 The entire stat sheet for fine tuned algorithms using all the information possible!
 */
 #[derive( Debug, Clone, Copy, PartialEq, Serialize, Deserialize)]
-pub struct Advanced<T:Copy 
-                 + Default
-                 + AddAssign
-                 + Add<Output = T>
-                 + Div<Output = T>
-                 + DivAssign
-                 + Mul<Output = T>
-                 + MulAssign
-                 + Neg<Output = T>
-                 + Rem<Output = T>
-                 + RemAssign
-                 + Sub<Output = T>
-                 + SubAssign
-                 + std::cmp::PartialOrd
-                 + num::NumCast> {
+pub struct Advanced<T:Copy
+    + Default
+    + Debug
+    + AddAssign
+    + Add<Output = T>
+    + Div<Output = T>
+    + DivAssign
+    + Mul<Output = T>
+    + MulAssign
+    + Neg<Output = T>
+    + Rem<Output = T>
+    + RemAssign
+    + Sub<Output = T>
+    + SubAssign
+    + std::cmp::PartialOrd
+    + num::NumCast> {
     /// Identification Number
     pub id:T,
     /// Experience Points
@@ -887,8 +910,9 @@ pub struct Advanced<T:Copy
     pub age:T,
     
 }
-impl<T:Copy 
+impl<T:Copy
     + Default
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
@@ -930,8 +954,9 @@ impl<T:Copy
         }
     }
 }
-impl<T:Copy 
+impl<T:Copy
     + Default
+    + Debug
     + AddAssign
     + Add<Output = T>
     + Div<Output = T>
@@ -951,3 +976,105 @@ impl<T:Copy
     }
 }
 
+/*
+# The FLTK
+
+This model provides fine tuning of attack and defense without needing all the fine tuning of a full stat sheet
+*/
+#[derive( Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[cfg_attr(feature = "fltkform", derive(FltkForm))]
+pub struct Stats {
+    /// Identification Number
+    pub id:f64,
+    // Name
+    pub name:String,
+    /// Experience Points
+    pub xp:f64,
+    /// Health Points
+    pub hp:f64,
+    /// Mana Points
+    pub mp:f64,
+    /// Experience Points multiplier for next level
+    pub xp_next:f64,
+    /// Max Health Points
+    pub hp_max:f64,
+    /// Max Mana Points
+    pub mp_max:f64,
+    /// Current Level
+    pub level:f64,
+    /// The speed
+    pub speed:f64,
+    /// your currency points
+    pub gp:f64,
+    /// Attack
+    pub atk:f64,
+    /// Defense
+    pub def:f64,
+    /// Mana Attack
+    pub m_atk:f64,
+    /// Mana Defense
+    pub m_def:f64,
+
+}
+impl Random for Stats {
+    type Type = Stats;
+    fn random_type(&self) -> Self::Type {
+        let hp = self.random(10.0,50.0);
+        let atk = self.random(5.0,50.0);
+        let def = self.random(5.0,50.0);
+        let mp = self.random(10.0,50.0);
+        let m_atk = self.random(5.0,50.0);
+        let m_def = self.random(5.0,50.0);
+        let speed = self.random(5.0,50.0);
+        let gp = self.random(0.0, 30.0);
+        Stats {
+            id:self.random(0.0, 100.0),
+            name:random_character_name(),
+            xp:0.0,
+            xp_next:10.0,
+            level:1.0,
+            hp_max:hp,
+            hp,
+            mp_max:mp,
+            mp,
+            atk,
+            def,
+            m_atk,
+            m_def,
+            speed,
+            gp,
+            
+        }
+    }
+    
+}
+impl Stats {
+    
+    /// make empty stats
+    pub fn empty() -> Self {
+        Stats {
+            name: String::from("Ferris"),
+            id:0.0,
+            xp:0.0,
+            xp_next:0.0,
+            mp:0.0,
+            hp:0.0,
+            mp_max:0.0,
+            hp_max:0.0,
+            level:0.0,
+            speed:0.0,
+            gp:0.0,
+            atk:0.0,
+            def:0.0,
+            m_atk:0.0,
+            m_def:0.0,
+        }
+    }
+}
+
+impl Default for Stats {
+    /// Default to empty
+    fn default() -> Self {
+        Self::empty()
+    }
+}
