@@ -7,20 +7,18 @@ mod tests {
     use crate::stats::Normal as StatsNormal;
     use crate::stats::BasicPremade as BasicPremade;
     use crate::stats::NormalPremade as NormalPremade;
-    //use crate::creature::Animal;
     // class
     use crate::class::Basic as Class;
     //use crate::class::Normal as NormalClass;
     
-    // legendary
-    use crate::legendary::Legendary;
     
     // special
-    use crate::special::ManaCost;
-    use crate::special::Normal as Special;
+    //use crate::special::ManaCost;
+    //use crate::special::Normal as Special;
 
     //atributes
     use crate::attributes::{Effectiveness, Value, Rate};
+    //etc
     use crate::equation::Equation;
 
 // imported libraries
@@ -56,12 +54,6 @@ char = 10
 wis = 10
 age = 10"#;
 
-
-    #[test]
-    fn special_type(){
-        let grind:Special = Special::Grind;
-        assert_eq!(grind.mp_cost(0), 7);
-    }
     // used in effectiveness test below
     #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
     pub struct OccasionalEnemy {
@@ -172,6 +164,48 @@ age = 10"#;
         }
     }
 
+    #[test]
+    fn attribute_test() {
+        use rpg_stat::creature::Stats;
+        use rpg_stat::random::Random;
+        //use rpg_stat::item::Item;
+        use rpg_stat::item::Normal as MyItem;
+
+        let mut stat = Stats::default();
+        stat = stat.random_type();
+        let captured = stat.check_capture();
+        if captured {
+          println!("Captured: {:?}", stat.name.to_owned());
+        }
+        if stat.check_encounter() {
+          println!("Found: {:?}", stat.name.to_owned());
+
+        }
+        if stat.heal(100.0) {
+          println!("Healed: {:?}", stat.name.to_owned());
+
+        }
+        if stat.use_item(1) {
+          println!("Used Item on {:?}", stat.name.to_owned());
+
+        }
+        if stat.get_item(1)  != MyItem::None {
+          println!("Got item #1 from: {:?}", stat.name.to_owned());
+
+        }
+        if !stat.remove_item(3) {
+          println!("{:?} has no item #3 to remove", stat.name.to_owned());
+
+        }
+        for item in stat.items() {
+            println!("Item: {:?}", item);
+        }
+        if stat.add_item(MyItem::Special) {
+            println!("Added Item 'Special'");
+        }
+        //let clone = stat.clone();
+        
+    }
     #[test]
     fn test_basic() {
         let b:Stats<f64> = Stats::default();
@@ -221,27 +255,7 @@ age = 10"#;
         assert_eq!(enemy.hp(), 5.0);
     }
     #[test]
-    fn legendary_builder() {
-        let sc:Legendary = Legendary::SantaClaus;
-        let stats:Stats<f64> = sc.build_basic(0.0,1.0);
-        assert_eq!(stats.hp,10.0);
-    }
-    #[test]
     fn serde_test_0(){
-        //let decoded:StatsNormal<f64> = toml::from_str(INI_FILE).unwrap();
-        //assert_eq!(decoded.hp, 10.0);
-        //assert_eq!(decoded.id, 1.0);
-    }
-    #[test]
-    fn serde_test_1() {
-        let sc:Legendary = Legendary::SantaClaus;
-        let stats:Stats<f64> = sc.build_basic(0.0,1.0);
-        let toml = toml::to_string(&stats).unwrap();
-        let stats_2:Stats<f64> = toml::from_str(&toml).unwrap();
-        assert_eq!(stats.hp, stats_2.hp);
-    }
-    #[test]
-    fn serde_test_2(){
         let decoded: Character = toml::from_str(INI_FILE).unwrap();
         assert_eq!(decoded.hp(), 10.0);
         assert_eq!(decoded.name, String::from("test"));
@@ -269,4 +283,10 @@ age = 10"#;
         // TODO
         println!("nothing");
     }
+    fn text_forms() {
+        //use crate::random::Random;
+        use crate::creature::Stats as Cs;
+        let c = Cs::default();
+        assert_eq!(c.hp, 0.0);
+    }
 } 
